/**
 * The java launcher is able to run a program
 * supplied as a single file of Java source code.
 *
 * @see <a href="https://openjdk.java.net/jeps/330">JEP 330: Launch Single-File Source-Code Programs</a>
 * @see <a href="https://openjdk.java.net/jeps/458">JEP 458: Launch Multi-File Source-Code Programs</a>
 */
class JEP330 {
    public static void main(String[] args) {
        System.out.println("Hello World");
    }
}
